@@ -6,18 +6,18 @@ import sys
 import pytest
 
 args = sys.argv[1:]
-if '--pyside' in args:
-    args.remove('--pyside')
-    import PySide
-elif '--pyqt4' in args:
-    args.remove('--pyqt4')
-    import PyQt4
-elif '--pyqt5' in args:
+if '--pyqt5' in args:
     args.remove('--pyqt5')
     import PyQt5
 elif '--pyside2' in args:
     args.remove('--pyside2')
     import PySide2
+elif '--pyside6' in args:
+    args.remove('--pyside6')
+    import PySide6
+elif '--pyqt6' in args:
+    args.remove('--pyqt6')
+    import PyQt6
 
 import pyqtgraph as pg
 pg.systemInfo()
