@@ -35,7 +35,7 @@ def test_signal_proxy_slot(qapp):
     sender = Sender(parent=qapp)
     receiver = Receiver(parent=qapp)
     proxy = SignalProxy(sender.signalSend, delay=0.0, rateLimit=0.6,
-                        slot=receiver.slotReceive)
+                        slot=receiver.slotReceive, threadSafe=False)
 
     assert proxy.blockSignal is False
     assert proxy is not None
@@ -54,7 +54,7 @@ def test_signal_proxy_disconnect_slot(qapp):
     sender = Sender(parent=qapp)
     receiver = Receiver(parent=qapp)
     proxy = SignalProxy(sender.signalSend, delay=0.0, rateLimit=0.6,
-                        slot=receiver.slotReceive)
+                        slot=receiver.slotReceive, threadSafe=False)
 
     assert proxy.blockSignal is False
     assert proxy is not None
@@ -77,7 +77,8 @@ def test_signal_proxy_no_slot_start(qapp):
     """Test the connect mode of SignalProxy without slot at start`"""
     sender = Sender(parent=qapp)
     receiver = Receiver(parent=qapp)
-    proxy = SignalProxy(sender.signalSend, delay=0.0, rateLimit=0.6)
+    proxy = SignalProxy(sender.signalSend, delay=0.0, rateLimit=0.6,
+                        threadSafe=False)
 
     assert proxy.blockSignal is True
     assert proxy is not None
@@ -107,7 +108,7 @@ def test_signal_proxy_slot_block(qapp):
     sender = Sender(parent=qapp)
     receiver = Receiver(parent=qapp)
     proxy = SignalProxy(sender.signalSend, delay=0.0, rateLimit=0.6,
-                        slot=receiver.slotReceive)
+                        slot=receiver.slotReceive, threadSafe=False)
 
     assert proxy.blockSignal is False
     assert proxy is not None
